MontePostProcess

Trait MontePostProcess 

pub trait MontePostProcess {
    // Required methods
    fn mean_project_duration(&self) -> f32;
    fn median_project_duration(&self) -> f32;
    fn task_criticality(&self) -> Vec<(String, f32)>;
}
A trait the provides post processing analyses over multiple PERT runs where one has sampled their tasks distributions many times.

Required Methods

fn mean_project_duration(&self) -> f32

Returns the mean project duration across all the runs.

fn median_project_duration(&self) -> f32

Returns the median project duration.

fn task_criticality(&self) -> Vec<(String, f32)>

Computes the ratio of how often the tasks exist on the critical path. Monte-Carlo simulations help identify the tasks that are always on the critical path and those that may be based on how the various task durations play out.

Implementations on Foreign Types

Source

impl MontePostProcess for Vec<Vec<PertTask>>

Source

fn mean_project_duration(&self) -> f32

Find the mean project duration

Source

fn median_project_duration(&self) -> f32

Find the median project duration

Source

fn task_criticality(&self) -> Vec<(String, f32)>

Report the ratio of how often the task lies on the critical path across all the PERT runs.

Implementors