pub trait MontePostProcess {
// Required methods
fn mean_project_duration(&self) -> f32;
fn median_project_duration(&self) -> f32;
fn task_criticality(&self) -> Vec<(String, f32)>;
}Expand description
A trait the provides post processing analyses over multiple PERT runs where one has sampled their tasks distributions many times.
Required Methods
Sourcefn mean_project_duration(&self) -> f32
fn mean_project_duration(&self) -> f32
Returns the mean project duration across all the runs.
Sourcefn median_project_duration(&self) -> f32
fn median_project_duration(&self) -> f32
Returns the median project duration.
Sourcefn task_criticality(&self) -> Vec<(String, f32)>
fn task_criticality(&self) -> Vec<(String, f32)>
Computes the ratio of how often the tasks exist on the critical path. Monte-Carlo simulations help identify the tasks that are always on the critical path and those that may be based on how the various task durations play out.
Implementations on Foreign Types
Sourceimpl MontePostProcess for Vec<Vec<PertTask>>
impl MontePostProcess for Vec<Vec<PertTask>>
Sourcefn mean_project_duration(&self) -> f32
fn mean_project_duration(&self) -> f32
Find the mean project duration
Sourcefn median_project_duration(&self) -> f32
fn median_project_duration(&self) -> f32
Find the median project duration